@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
@@ -87,31 +89,31 @@ class OracleProfile(proto.Message):
             Required. Password for the Oracle connection.
         database_service (str):
             Required. Database for the Oracle connection.
-        connection_attributes (Mapping[str, str]):
+        connection_attributes (MutableMapping[str, str]):
             Connection string attributes
     """
 
-    hostname = proto.Field(
+    hostname: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    port = proto.Field(
+    port: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    username = proto.Field(
+    username: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    password = proto.Field(
+    password: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    database_service = proto.Field(
+    database_service: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    connection_attributes = proto.MapField(
+    connection_attributes: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=6,
@@ -136,23 +138,23 @@ class MysqlProfile(proto.Message):
             SSL configuration for the MySQL connection.
     """
 
-    hostname = proto.Field(
+    hostname: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    port = proto.Field(
+    port: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    username = proto.Field(
+    username: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    password = proto.Field(
+    password: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    ssl_config = proto.Field(
+    ssl_config: "MysqlSslConfig" = proto.Field(
         proto.MESSAGE,
         number=5,
         message="MysqlSslConfig",
@@ -171,11 +173,11 @@ class GcsProfile(proto.Message):
             bucket.
     """
 
-    bucket_name = proto.Field(
+    bucket_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    root_path = proto.Field(
+    root_path: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -216,24 +218,24 @@ class ForwardSshTunnelConnectivity(proto.Message):
             This field is a member of `oneof`_ ``authentication_method``.
     """
 
-    hostname = proto.Field(
+    hostname: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    username = proto.Field(
+    username: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    port = proto.Field(
+    port: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    password = proto.Field(
+    password: str = proto.Field(
         proto.STRING,
         number=100,
         oneof="authentication_method",
     )
-    private_key = proto.Field(
+    private_key: str = proto.Field(
         proto.STRING,
         number=101,
         oneof="authentication_method",
@@ -253,11 +255,11 @@ class VpcPeeringConfig(proto.Message):
             /29)
     """
 
-    vpc_name = proto.Field(
+    vpc_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    subnet = proto.Field(
+    subnet: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -274,7 +276,7 @@ class PrivateConnection(proto.Message):
             Output only. The create time of the resource.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The update time of the resource.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             Labels.
         display_name (str):
             Required. Display name.
@@ -295,40 +297,40 @@ class PrivateConnection(proto.Message):
         CREATED = 2
         FAILED = 3
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=4,
     )
-    display_name = proto.Field(
+    display_name: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=6,
         enum=State,
     )
-    error = proto.Field(
+    error: "Error" = proto.Field(
         proto.MESSAGE,
         number=7,
         message="Error",
     )
-    vpc_peering_config = proto.Field(
+    vpc_peering_config: "VpcPeeringConfig" = proto.Field(
         proto.MESSAGE,
         number=100,
         message="VpcPeeringConfig",
@@ -343,7 +345,7 @@ class PrivateConnectivity(proto.Message):
 
     """
 
-    private_connection_name = proto.Field(
+    private_connection_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -361,7 +363,7 @@ class Route(proto.Message):
             Output only. The create time of the resource.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The update time of the resource.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             Labels.
         display_name (str):
             Required. Display name.
@@ -371,34 +373,34 @@ class Route(proto.Message):
             Destination port for connection
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=4,
     )
-    display_name = proto.Field(
+    display_name: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    destination_address = proto.Field(
+    destination_address: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    destination_port = proto.Field(
+    destination_port: int = proto.Field(
         proto.INT32,
         number=7,
     )
@@ -432,27 +434,27 @@ class MysqlSslConfig(proto.Message):
             set.
     """
 
-    client_key = proto.Field(
+    client_key: str = proto.Field(
         proto.STRING,
         number=11,
     )
-    client_key_set = proto.Field(
+    client_key_set: bool = proto.Field(
         proto.BOOL,
         number=12,
     )
-    client_certificate = proto.Field(
+    client_certificate: str = proto.Field(
         proto.STRING,
         number=13,
     )
-    client_certificate_set = proto.Field(
+    client_certificate_set: bool = proto.Field(
         proto.BOOL,
         number=14,
     )
-    ca_certificate = proto.Field(
+    ca_certificate: str = proto.Field(
         proto.STRING,
         number=15,
     )
-    ca_certificate_set = proto.Field(
+    ca_certificate_set: bool = proto.Field(
         proto.BOOL,
         number=16,
     )
@@ -475,7 +477,7 @@ class ConnectionProfile(proto.Message):
             Output only. The create time of the resource.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The update time of the resource.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             Labels.
         display_name (str):
             Required. Display name.
@@ -510,66 +512,66 @@ class ConnectionProfile(proto.Message):
             This field is a member of `oneof`_ ``connectivity``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=4,
     )
-    display_name = proto.Field(
+    display_name: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    oracle_profile = proto.Field(
+    oracle_profile: "OracleProfile" = proto.Field(
         proto.MESSAGE,
         number=100,
         oneof="profile",
         message="OracleProfile",
     )
-    gcs_profile = proto.Field(
+    gcs_profile: "GcsProfile" = proto.Field(
         proto.MESSAGE,
         number=101,
         oneof="profile",
         message="GcsProfile",
     )
-    mysql_profile = proto.Field(
+    mysql_profile: "MysqlProfile" = proto.Field(
         proto.MESSAGE,
         number=102,
         oneof="profile",
         message="MysqlProfile",
     )
-    no_connectivity = proto.Field(
+    no_connectivity: "NoConnectivitySettings" = proto.Field(
         proto.MESSAGE,
         number=200,
         oneof="connectivity",
         message="NoConnectivitySettings",
     )
-    static_service_ip_connectivity = proto.Field(
+    static_service_ip_connectivity: "StaticServiceIpConnectivity" = proto.Field(
         proto.MESSAGE,
         number=201,
         oneof="connectivity",
         message="StaticServiceIpConnectivity",
     )
-    forward_ssh_connectivity = proto.Field(
+    forward_ssh_connectivity: "ForwardSshTunnelConnectivity" = proto.Field(
         proto.MESSAGE,
         number=202,
         oneof="connectivity",
         message="ForwardSshTunnelConnectivity",
     )
-    private_connectivity = proto.Field(
+    private_connectivity: "PrivateConnectivity" = proto.Field(
         proto.MESSAGE,
         number=203,
         oneof="connectivity",
@@ -604,39 +606,39 @@ class OracleColumn(proto.Message):
             table.
     """
 
-    column_name = proto.Field(
+    column_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    data_type = proto.Field(
+    data_type: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    length = proto.Field(
+    length: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    precision = proto.Field(
+    precision: int = proto.Field(
         proto.INT32,
         number=4,
     )
-    scale = proto.Field(
+    scale: int = proto.Field(
         proto.INT32,
         number=5,
     )
-    encoding = proto.Field(
+    encoding: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    primary_key = proto.Field(
+    primary_key: bool = proto.Field(
         proto.BOOL,
         number=7,
     )
-    nullable = proto.Field(
+    nullable: bool = proto.Field(
         proto.BOOL,
         number=8,
     )
-    ordinal_position = proto.Field(
+    ordinal_position: int = proto.Field(
         proto.INT32,
         number=9,
     )
@@ -648,17 +650,17 @@ class OracleTable(proto.Message):
     Attributes:
         table_name (str):
             Table name.
-        oracle_columns (Sequence[google.cloud.datastream_v1alpha1.types.OracleColumn]):
+        oracle_columns (MutableSequence[google.cloud.datastream_v1alpha1.types.OracleColumn]):
             Oracle columns in the schema.
             When unspecified as part of inclue/exclude
             lists, includes/excludes everything.
     """
 
-    table_name = proto.Field(
+    table_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    oracle_columns = proto.RepeatedField(
+    oracle_columns: MutableSequence["OracleColumn"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="OracleColumn",
@@ -671,15 +673,15 @@ class OracleSchema(proto.Message):
     Attributes:
         schema_name (str):
             Schema name.
-        oracle_tables (Sequence[google.cloud.datastream_v1alpha1.types.OracleTable]):
+        oracle_tables (MutableSequence[google.cloud.datastream_v1alpha1.types.OracleTable]):
             Tables in the schema.
     """
 
-    schema_name = proto.Field(
+    schema_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    oracle_tables = proto.RepeatedField(
+    oracle_tables: MutableSequence["OracleTable"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="OracleTable",
@@ -690,12 +692,12 @@ class OracleRdbms(proto.Message):
     r"""Oracle database structure.
 
     Attributes:
-        oracle_schemas (Sequence[google.cloud.datastream_v1alpha1.types.OracleSchema]):
+        oracle_schemas (MutableSequence[google.cloud.datastream_v1alpha1.types.OracleSchema]):
             Oracle schemas/databases in the database
             server.
     """
 
-    oracle_schemas = proto.RepeatedField(
+    oracle_schemas: MutableSequence["OracleSchema"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="OracleSchema",
@@ -712,12 +714,12 @@ class OracleSourceConfig(proto.Message):
             Oracle objects to exclude from the stream.
     """
 
-    allowlist = proto.Field(
+    allowlist: "OracleRdbms" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="OracleRdbms",
     )
-    rejectlist = proto.Field(
+    rejectlist: "OracleRdbms" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="OracleRdbms",
@@ -749,31 +751,31 @@ class MysqlColumn(proto.Message):
             table.
     """
 
-    column_name = proto.Field(
+    column_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    data_type = proto.Field(
+    data_type: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    length = proto.Field(
+    length: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    collation = proto.Field(
+    collation: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    primary_key = proto.Field(
+    primary_key: bool = proto.Field(
         proto.BOOL,
         number=5,
     )
-    nullable = proto.Field(
+    nullable: bool = proto.Field(
         proto.BOOL,
         number=6,
     )
-    ordinal_position = proto.Field(
+    ordinal_position: int = proto.Field(
         proto.INT32,
         number=7,
     )
@@ -785,17 +787,17 @@ class MysqlTable(proto.Message):
     Attributes:
         table_name (str):
             Table name.
-        mysql_columns (Sequence[google.cloud.datastream_v1alpha1.types.MysqlColumn]):
+        mysql_columns (MutableSequence[google.cloud.datastream_v1alpha1.types.MysqlColumn]):
             MySQL columns in the database.
             When unspecified as part of include/exclude
             lists, includes/excludes everything.
     """
 
-    table_name = proto.Field(
+    table_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    mysql_columns = proto.RepeatedField(
+    mysql_columns: MutableSequence["MysqlColumn"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="MysqlColumn",
@@ -808,15 +810,15 @@ class MysqlDatabase(proto.Message):
     Attributes:
         database_name (str):
             Database name.
-        mysql_tables (Sequence[google.cloud.datastream_v1alpha1.types.MysqlTable]):
+        mysql_tables (MutableSequence[google.cloud.datastream_v1alpha1.types.MysqlTable]):
             Tables in the database.
     """
 
-    database_name = proto.Field(
+    database_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    mysql_tables = proto.RepeatedField(
+    mysql_tables: MutableSequence["MysqlTable"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="MysqlTable",
@@ -827,11 +829,11 @@ class MysqlRdbms(proto.Message):
     r"""MySQL database structure
 
     Attributes:
-        mysql_databases (Sequence[google.cloud.datastream_v1alpha1.types.MysqlDatabase]):
+        mysql_databases (MutableSequence[google.cloud.datastream_v1alpha1.types.MysqlDatabase]):
             Mysql databases on the server
     """
 
-    mysql_databases = proto.RepeatedField(
+    mysql_databases: MutableSequence["MysqlDatabase"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="MysqlDatabase",
@@ -848,12 +850,12 @@ class MysqlSourceConfig(proto.Message):
             MySQL objects to exclude from the stream.
     """
 
-    allowlist = proto.Field(
+    allowlist: "MysqlRdbms" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="MysqlRdbms",
     )
-    rejectlist = proto.Field(
+    rejectlist: "MysqlRdbms" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="MysqlRdbms",
@@ -884,17 +886,17 @@ class SourceConfig(proto.Message):
             This field is a member of `oneof`_ ``source_stream_config``.
     """
 
-    source_connection_profile_name = proto.Field(
+    source_connection_profile_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    oracle_source_config = proto.Field(
+    oracle_source_config: "OracleSourceConfig" = proto.Field(
         proto.MESSAGE,
         number=100,
         oneof="source_stream_config",
         message="OracleSourceConfig",
     )
-    mysql_source_config = proto.Field(
+    mysql_source_config: "MysqlSourceConfig" = proto.Field(
         proto.MESSAGE,
         number=101,
         oneof="source_stream_config",
@@ -922,12 +924,12 @@ class JsonFileFormat(proto.Message):
         NO_COMPRESSION = 1
         GZIP = 2
 
-    schema_file_format = proto.Field(
+    schema_file_format: "SchemaFileFormat" = proto.Field(
         proto.ENUM,
         number=1,
         enum="SchemaFileFormat",
     )
-    compression = proto.Field(
+    compression: JsonCompression = proto.Field(
         proto.ENUM,
         number=2,
         enum=JsonCompression,
@@ -968,31 +970,31 @@ class GcsDestinationConfig(proto.Message):
             This field is a member of `oneof`_ ``file_format``.
     """
 
-    path = proto.Field(
+    path: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    gcs_file_format = proto.Field(
+    gcs_file_format: "GcsFileFormat" = proto.Field(
         proto.ENUM,
         number=2,
         enum="GcsFileFormat",
     )
-    file_rotation_mb = proto.Field(
+    file_rotation_mb: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    file_rotation_interval = proto.Field(
+    file_rotation_interval: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=4,
         message=duration_pb2.Duration,
     )
-    avro_file_format = proto.Field(
+    avro_file_format: "AvroFileFormat" = proto.Field(
         proto.MESSAGE,
         number=100,
         oneof="file_format",
         message="AvroFileFormat",
     )
-    json_file_format = proto.Field(
+    json_file_format: "JsonFileFormat" = proto.Field(
         proto.MESSAGE,
         number=101,
         oneof="file_format",
@@ -1014,11 +1016,11 @@ class DestinationConfig(proto.Message):
             This field is a member of `oneof`_ ``destination_stream_config``.
     """
 
-    destination_connection_profile_name = proto.Field(
+    destination_connection_profile_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    gcs_destination_config = proto.Field(
+    gcs_destination_config: "GcsDestinationConfig" = proto.Field(
         proto.MESSAGE,
         number=100,
         oneof="destination_stream_config",
@@ -1044,7 +1046,7 @@ class Stream(proto.Message):
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The last update time of the
             stream.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             Labels.
         display_name (str):
             Required. Display name.
@@ -1066,7 +1068,7 @@ class Stream(proto.Message):
             Do not automatically backfill any objects.
 
             This field is a member of `oneof`_ ``backfill_strategy``.
-        errors (Sequence[google.cloud.datastream_v1alpha1.types.Error]):
+        errors (MutableSequence[google.cloud.datastream_v1alpha1.types.Error]):
             Output only. Errors on the Stream.
     """
 
@@ -1106,13 +1108,13 @@ class Stream(proto.Message):
                 This field is a member of `oneof`_ ``excluded_objects``.
         """
 
-        oracle_excluded_objects = proto.Field(
+        oracle_excluded_objects: "OracleRdbms" = proto.Field(
             proto.MESSAGE,
             number=1,
             oneof="excluded_objects",
             message="OracleRdbms",
         )
-        mysql_excluded_objects = proto.Field(
+        mysql_excluded_objects: "MysqlRdbms" = proto.Field(
             proto.MESSAGE,
             number=2,
             oneof="excluded_objects",
@@ -1125,57 +1127,57 @@ class Stream(proto.Message):
 
         """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=4,
     )
-    display_name = proto.Field(
+    display_name: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    source_config = proto.Field(
+    source_config: "SourceConfig" = proto.Field(
         proto.MESSAGE,
         number=6,
         message="SourceConfig",
     )
-    destination_config = proto.Field(
+    destination_config: "DestinationConfig" = proto.Field(
         proto.MESSAGE,
         number=7,
         message="DestinationConfig",
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=8,
         enum=State,
     )
-    backfill_all = proto.Field(
+    backfill_all: BackfillAllStrategy = proto.Field(
         proto.MESSAGE,
         number=101,
         oneof="backfill_strategy",
         message=BackfillAllStrategy,
     )
-    backfill_none = proto.Field(
+    backfill_none: BackfillNoneStrategy = proto.Field(
         proto.MESSAGE,
         number=102,
         oneof="backfill_strategy",
         message=BackfillNoneStrategy,
     )
-    errors = proto.RepeatedField(
+    errors: MutableSequence["Error"] = proto.RepeatedField(
         proto.MESSAGE,
         number=9,
         message="Error",
@@ -1198,28 +1200,28 @@ class Error(proto.Message):
             the error that occurred.
         error_time (google.protobuf.timestamp_pb2.Timestamp):
             The time when the error occurred.
-        details (Mapping[str, str]):
+        details (MutableMapping[str, str]):
             Additional information about the error.
     """
 
-    reason = proto.Field(
+    reason: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    error_uuid = proto.Field(
+    error_uuid: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    message = proto.Field(
+    message: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    error_time = proto.Field(
+    error_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=4,
         message=timestamp_pb2.Timestamp,
     )
-    details = proto.MapField(
+    details: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=5,
@@ -1230,12 +1232,12 @@ class ValidationResult(proto.Message):
     r"""Contains the current validation results.
 
     Attributes:
-        validations (Sequence[google.cloud.datastream_v1alpha1.types.Validation]):
+        validations (MutableSequence[google.cloud.datastream_v1alpha1.types.Validation]):
             A list of validations (includes both executed
             as well as not executed validations).
     """
 
-    validations = proto.RepeatedField(
+    validations: MutableSequence["Validation"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="Validation",
@@ -1250,7 +1252,7 @@ class Validation(proto.Message):
             A short description of the validation.
         status (google.cloud.datastream_v1alpha1.types.Validation.Status):
             Validation execution status.
-        message (Sequence[google.cloud.datastream_v1alpha1.types.ValidationMessage]):
+        message (MutableSequence[google.cloud.datastream_v1alpha1.types.ValidationMessage]):
             Messages reflecting the validation results.
         code (str):
             A custom code identifying this validation.
@@ -1263,21 +1265,21 @@ class Validation(proto.Message):
         FAILED = 2
         PASSED = 3
 
-    description = proto.Field(
+    description: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    status = proto.Field(
+    status: Status = proto.Field(
         proto.ENUM,
         number=2,
         enum=Status,
     )
-    message = proto.RepeatedField(
+    message: MutableSequence["ValidationMessage"] = proto.RepeatedField(
         proto.MESSAGE,
         number=3,
         message="ValidationMessage",
     )
-    code = proto.Field(
+    code: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -1291,7 +1293,7 @@ class ValidationMessage(proto.Message):
             The result of the validation.
         level (google.cloud.datastream_v1alpha1.types.ValidationMessage.Level):
             Message severity level (warning or error).
-        metadata (Mapping[str, str]):
+        metadata (MutableMapping[str, str]):
             Additional metadata related to the result.
         code (str):
             A custom code identifying this specific
@@ -1304,21 +1306,21 @@ class ValidationMessage(proto.Message):
         WARNING = 1
         ERROR = 2
 
-    message = proto.Field(
+    message: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    level = proto.Field(
+    level: Level = proto.Field(
         proto.ENUM,
         number=2,
         enum=Level,
     )
-    metadata = proto.MapField(
+    metadata: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=3,
     )
-    code = proto.Field(
+    code: str = proto.Field(
         proto.STRING,
         number=4,
     )
